@@ -90,6 +90,8 @@ class _SlimsApi(object):
                                                token_updater=token_updater)
 
     def get_entities(self, url, body=None):
+        if(self.url.startswith('https') and url.startswith('http') and url[4:].startswith(self.url[5:])):
+            url = 'https' + url[4:]
         if not url.startswith(self.url):
             url = self.url + url
 
@@ -317,7 +319,7 @@ class Slims(object):
         Examples:
             >>> slims.add("Content", {
                     "cntn_id", "ID",
-                    "cntn_status", Status.PENDING,
+                    "cntn_status", Status.PENDING.value,
                     "cntn_fk_contentType", 1
                 })
 
@@ -452,7 +454,7 @@ class Record(object):
 
         Examples:
             >>> content = slims.fetch_by_pk("Content", 1)
-                content.update({"cntn_id", "new id"})
+                content.update({"cntn_id": "new id"})
 
             Fetches the content record with primary key 1 and changes
             its id to "new id"
